==> keycloak-model-map-18.0.2-sources.jar: org/keycloak/models/map/realm/entity/MapAuthenticationFlowEntityDelegate.java <==
package org.keycloak.models.map.realm.entity;
public class MapAuthenticationFlowEntityDelegate implements org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntity {
    private final org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntity> delegateProvider;
    public MapAuthenticationFlowEntityDelegate(org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntity> delegateProvider) {
        this.delegateProvider = delegateProvider;
    }
    @Override public boolean isUpdated() {
        return delegateProvider.isUpdated();
    }
    @Override public String getId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntityFields.ID).getId();
    }
    @Override public void setId(String id) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntityFields.ID, id).setId(id);
    }
    @Override public String getAlias() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntityFields.ALIAS).getAlias();
    }
    @Override public void setAlias(String alias) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntityFields.ALIAS, alias).setAlias(alias);
    }
    @Override public String getDescription() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntityFields.DESCRIPTION).getDescription();
    }
    @Override public void setDescription(String description) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntityFields.DESCRIPTION, description).setDescription(description);
    }
    @Override public String getProviderId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntityFields.PROVIDER_ID).getProviderId();
    }
    @Override public void setProviderId(String providerId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntityFields.PROVIDER_ID, providerId).setProviderId(providerId);
    }
    @Override public Boolean isBuiltIn() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntityFields.BUILT_IN).isBuiltIn();
    }
    @Override public void setBuiltIn(Boolean builtIn) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntityFields.BUILT_IN, builtIn).setBuiltIn(builtIn);
    }
    @Override public Boolean isTopLevel() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntityFields.TOP_LEVEL).isTopLevel();
    }
    @Override public void setTopLevel(Boolean topLevel) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntityFields.TOP_LEVEL, topLevel).setTopLevel(topLevel);
    }
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/realm/entity/MapAuthenticationFlowEntityDelegate.java <==
package org.keycloak.models.map.realm.entity;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapAuthenticationFlowEntityDelegate implements org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntity, org.keycloak.models.map.common.delegate.HasDelegateProvider<org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntity> {
    private final org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntity> delegateProvider;
    public MapAuthenticationFlowEntityDelegate(org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntity> delegateProvider) {
        this.delegateProvider = delegateProvider;
    }
    public org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntity> getDelegateProvider() {
        return this.delegateProvider;
    }
    @Override public boolean isUpdated() {
        return delegateProvider.isUpdated();
    }
    @Override public String getId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntityFields.ID).getId();
    }
    @Override public void setId(String id) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntityFields.ID, id).setId(id);
    }
    @Override public String getAlias() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntityFields.ALIAS).getAlias();
    }
    @Override public void setAlias(String alias) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntityFields.ALIAS, alias).setAlias(alias);
    }
    @Override public String getDescription() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntityFields.DESCRIPTION).getDescription();
    }
    @Override public void setDescription(String description) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntityFields.DESCRIPTION, description).setDescription(description);
    }
    @Override public String getProviderId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntityFields.PROVIDER_ID).getProviderId();
    }
    @Override public void setProviderId(String providerId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntityFields.PROVIDER_ID, providerId).setProviderId(providerId);
    }
    @Override public Boolean isBuiltIn() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntityFields.BUILT_IN).isBuiltIn();
    }
    @Override public void setBuiltIn(Boolean builtIn) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntityFields.BUILT_IN, builtIn).setBuiltIn(builtIn);
    }
    @Override public Boolean isTopLevel() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntityFields.TOP_LEVEL).isTopLevel();
    }
    @Override public void setTopLevel(Boolean topLevel) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntityFields.TOP_LEVEL, topLevel).setTopLevel(topLevel);
    }
}
